# OpenBB Platform v4 Cookiecutter Template

## Introduction

This is the generated cookiecutter template for the OpenBB Platform v4.
It is used to help you create a new extension that can be integrated into the existing structure of the OpenBB Platform.

With it you can:

* Create a new extension
* Build custom commands
* Interact with the standardization framework
* Build custom services and applications on top of the framework

## Getting Started

We recommend you check out the files in the following order:

* `openbb_orats/README.md`
* `openbb_orats/models/example.py`
* `openbb_orats/provider.py`
* `openbb_orats/__init__.py`
* `openbb_orats/router.py`
